Overview
========

Chameleon is an HTML/XML template engine for `Python
<http://www.python.org>`_. It uses the *page templates* language.

You can use it in any Python web application with just about any
version of Python (2.5 and up, including 3.x and `pypy
<http://pypy.org>`_).

Visit the `website <http://pagetemplates.org>`_ for more information
or the `documentation <http://pagetemplates.org/docs/latest/>`_.

License and Copyright
---------------------

This software is made available as-is under a BSD-like license [1]_
(see included copyright notice).


Notes
-----

.. [1] This software is licensed under the `Repoze
       <http://repoze.org/license.html>`_ license.
